summaryrefslogtreecommitdiff
path: root/framework/Web/UI/ActiveControls/TActiveDataGrid.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/ActiveControls/TActiveDataGrid.php')
-rw-r--r--framework/Web/UI/ActiveControls/TActiveDataGrid.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/framework/Web/UI/ActiveControls/TActiveDataGrid.php b/framework/Web/UI/ActiveControls/TActiveDataGrid.php
index 13ba650a..bd32db5e 100644
--- a/framework/Web/UI/ActiveControls/TActiveDataGrid.php
+++ b/framework/Web/UI/ActiveControls/TActiveDataGrid.php
@@ -84,7 +84,7 @@ class TActiveDataGrid extends TDataGrid implements IActiveControl, ISurroundable
}
/**
* Returns the id of the surrounding container (span).
* @return string container id
*/
public function getSurroundingTagId() {
@@ -158,14 +158,14 @@ class TActiveDataGrid extends TDataGrid implements IActiveControl, ISurroundable
}
/**
- * Renders the datagrid by writing a span tag with the container id obtained from {@link getSurroundingTagId()}
+ * Renders the datagrid by writing a div tag with the container id obtained from {@link getSurroundingTagId()}
* which will be called by the replacement method of the client script to update it's content.
* @param THtmlWriter writer for the rendering purpose
*/
private function renderDataGrid($writer) {
- $writer->write('<span id="'.$this->getSurroundingTagId().'">');
+ $writer->write('<div id="'.$this->getSurroundingTagId().'">');
parent::render($writer);
- $writer->write('</span>');
+ $writer->write('</div>');
}
}
@@ -84,7 +84,7 @@ class TActiveDataGrid extends TDataGrid implements IActiveControl, ISurroundable
}
/**
- * Returns the id of the surrounding container (span).
+ * Returns the id of the surrounding container (div).
* @return string container id
*/